==> mono-1.2.5.1.tar.bz2: mono-1.2.5.1/mcs/class/System/System.ComponentModel/TypeDescriptionProviderAttribute.cs <==
//
// TypeDescriptionProviderAttribute.cs
//
// Author:
//	Atsushi Enomoto  <atsushi@ximian.com>
//
// Copyright (C) 2007 Novell, Inc. http://www.novell.com
//

//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

#if NET_2_0

using System;

namespace System.ComponentModel
{
	[AttributeUsage (AttributeTargets.Class)]
	public sealed class TypeDescriptionProviderAttribute : Attribute
	{
		string type;

		[MonoTODO]
		public TypeDescriptionProviderAttribute (string typeName)
		{
			if (typeName == null)
				throw new ArgumentNullException ("typeName");
			type = typeName;
		}

		[MonoTODO]
		public TypeDescriptionProviderAttribute (Type type)
		{
			if (type== null)
				throw new ArgumentNullException ("type");
			this.type = type.AssemblyQualifiedName;
		}

		public string TypeName {
			get { return type; }
		}
	}
}

#endif

==> mono-2.4.3.tar.bz2: mono-2.4.3/mcs/class/System/System.ComponentModel/TypeDescriptionProviderAttribute.cs <==
//
// System.ComponentModel.TypeDescriptionProviderAttribute
//
// Authors:		
//		Ivan N. Zlatev (contact i-nZ.net)
//
// (C) 2007 Ivan N. Zlatev

//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

#if NET_2_0

namespace System.ComponentModel
{
	[AttributeUsage(AttributeTargets.Class, Inherited=true)]
	public sealed class TypeDescriptionProviderAttribute : Attribute
	{
		private string typeName;

		public string TypeName { 
			get { return this.typeName; }
		}

		public TypeDescriptionProviderAttribute (string typeName)
		{
			if (typeName == null)
				throw new System.ArgumentNullException ("typeName");

			this.typeName = typeName;
		}
		
		public TypeDescriptionProviderAttribute (Type type)
		{
			if (type == null)
				throw new System.ArgumentNullException ("type");

			this.typeName = type.AssemblyQualifiedName;
		}
		
	}

}
#endif
